<?php
/**
 * WP-CDN-Yes 缓存刷新
 * @author 耗子
 * @created 2020-12-20
 * @updated 2021-10-17
 */

defined('ABSPATH') || exit;
if ( ! class_exists( 'WPCDN_Refresh' ) ):
	class WPCDN_Refresh {

		private $settings_api;
		private $wpcy_cdn_select;
		private $wpcy_cdn_id;
		private $wpcy_cdn_key;
		private $wpcy_cdn_refresh_type;

		function __construct() {
			// 设置API
			$this->settings_api          = new Easy_Setting;
			$this->wpcy_cdn_select       = $this->settings_api->get_option( 'wpcy_cdn_select', 'wpcy_basics' );
			$this->wpcy_cdn_id           = $this->settings_api->get_option( 'wpcy_cdn_id', 'wpcy_basics' );
			$this->wpcy_cdn_key          = $this->settings_api->get_option( 'wpcy_cdn_key', 'wpcy_basics' );
			$this->wpcy_cdn_refresh_type = $this->settings_api->get_option( 'wpcy_cdn_refresh_type', 'wpcy_advanced' );
			// 缓存清理
			if ( ! empty( $this->wpcy_cdn_id ) && ! empty( $this->wpcy_cdn_key ) ) {
				// 发布/更新文章
				if ( $this->settings_api->get_option( 'wpcy_cdn_refresh_publish', 'wpcy_basics' ) == 'on' ) {
					add_action( 'publish_post', array( $this, 'refresh_post' ), 0 );
					add_action( 'publish_future_post', array( $this, 'refresh_post' ), 0 );
				}
				// 文章移入/移出回收站
				if ( $this->settings_api->get_option( 'wpcy_cdn_refresh_trash', 'wpcy_basics' ) == 'on' ) {
					add_action( 'wp_trash_post', array( $this, 'refresh_post' ), 0 );
					add_action( 'untrashed_post', array( $this, 'refresh_post' ), 0 );
				}
				// 提交评论
				if ( $this->settings_api->get_option( 'wpcy_cdn_refresh_comment_submitted', 'wpcy_basics' ) == 'on' ) {
					add_action( 'comment_post', array( $this, 'refresh_comment' ), 0 );
				}
				// 评论通过审核
				if ( $this->settings_api->get_option( 'wpcy_cdn_refresh_comment_approved', 'wpcy_basics' ) == 'on' ) {
					add_action( 'comment_unapproved_to_approved', array( $this, 'refresh_comment_approved' ), 0 );
				}
				// 评论移入/移出回收站
				if ( $this->settings_api->get_option( 'wpcy_cdn_refresh_comment_trash', 'wpcy_basics' ) == 'on' ) {
					add_action( 'trash_comment', array( $this, 'refresh_comment' ), 0 );
					add_action( 'untrashed_comment', array( $this, 'refresh_comment' ), 0 );
				}
				// 分类新增/修改/删除
				if ( $this->settings_api->get_option( 'wpcy_cdn_refresh_category', 'wpcy_basics' ) == 'on' ) {
					add_action( 'create_category', array( $this, 'refresh_category' ), 0 );
					add_action( 'delete_category', array( $this, 'refresh_category' ), 0 );
					add_action( 'edit_category', array( $this, 'refresh_category' ), 0 );
				}
			}
		}

		function refresh( $data, $type = '', $postid = '' ) {
			$args = array(
				'wpcy_cdn_select' => $this->wpcy_cdn_select,
				'wpcy_cdn_id'     => $this->wpcy_cdn_id,
				'wpcy_cdn_key'    => $this->wpcy_cdn_key,
				'type'            => $type,
				'data'            => $data
			);
			$response = wp_remote_post( 'https://wp-cdn.cn/api/v1/refresh', array( 'body' => $args ) );
			if ( ! empty( $postid ) ) {
				update_post_meta( $postid, 'wpcy_refresh', $response );
			}
		}

		function refresh_post( $postid ) {
			// 检查目录刷新方式
			if ( $this->wpcy_cdn_refresh_type == 'dir' ) {
				self::refresh( home_url() . '/', 'Directory', $postid );
				return;
			}
			// 清理此文章
			self::refresh( get_permalink( $postid ), 'File', $postid );
			// 清理主页
			self::refresh( home_url() . '/', 'File' );
			// 清理相关分类页面
			if ( $categories = wp_get_post_categories( $postid ) ) {
				foreach ( $categories as $category_id ) {
					$cat_url = get_category_link( $category_id );
					self::refresh( $cat_url, 'File' );
				}
			}
			// 清理相关标签页面
			if ( $tags = get_the_tags( $postid ) ) {
				foreach ( $tags as $tag ) {
					$tag_url = get_tag_link( $tag->term_id );
					self::refresh( $tag_url, 'File' );
				}
			}
		}

		function refresh_comment_approved( $comment ) {
			// 检查目录刷新方式
			if ( $this->wpcy_cdn_refresh_type == 'dir' ) {
				self::refresh( home_url() . '/', 'Directory' );

				return;
			}
			// 清理文章
			self::refresh( get_permalink( $comment->comment_post_ID ), 'File', $comment->comment_post_ID );
			// 清理主页
			self::refresh( home_url() . '/', 'File' );
		}

		function refresh_comment( $comment_id ) {
			// 检查目录刷新方式
			if ( $this->wpcy_cdn_refresh_type == 'dir' ) {
				self::refresh( home_url() . '/', 'Directory' );

				return;
			}
			// 清理文章
			self::refresh( get_permalink( get_comment( $comment_id )->comment_post_ID ), 'File', get_comment( $comment_id )->comment_post_ID );
			// 清理主页
			self::refresh( home_url() . '/', 'File' );
		}

		function refresh_category( $category_id ) {
			// 检查目录刷新方式
			if ( $this->wpcy_cdn_refresh_type == 'dir' ) {
				self::refresh( home_url() . '/', 'Directory' );

				return;
			}
			// 清理分类
			self::refresh( get_category_link( $category_id ), 'File' );
			// 清理主页
			self::refresh( home_url() . '/', 'File' );
		}
	}
endif;
