<?php
/**
 * WP-CDN-Yes 设置页面
 * @author 耗子
 * @created 2020-12-20
 * @updated 2021-10-17
 */

defined('ABSPATH') || exit;
if ( ! class_exists( 'WPCDN_Settings' ) ):
	class WPCDN_Settings {

		private $settings_api;

		function __construct() {
			//设置API
			$this->settings_api = new Easy_Setting;

			add_action( 'admin_init', array( $this, 'admin_init' ) );
			add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		}

		function admin_init() {

			//set the settings
			$this->settings_api->set_sections( $this->get_settings_sections() );
			$this->settings_api->set_fields( $this->get_settings_fields() );

			//initialize settings
			$this->settings_api->admin_init();

            /**待完成功能2020-1-1
             * add_action( 'wp_dashboard_setup', function () {
				 * wp_add_dashboard_widget('sponsor_widget', 'WP-CDN-Yes', function () {
				 * });
			} );*/

			add_action( 'add_meta_boxes', function () {
				add_meta_box( 'wpcy_refresh', esc_html__( 'WP-CDN-Yes', 'wp-cdn-yes' ), 'wpcy_refresh_status', 'post', 'side', 'low' );
				function wpcy_refresh_status() {
					global $post;
					$refresh_status = get_post_meta( $post->ID, 'wpcy_refresh', true );
					if ( $refresh_status ) {
						$refresh_message = json_decode( $refresh_status['body'] );
						echo '<p><strong>缓存刷新：' . ( isset( $refresh_message->code ) && $refresh_message->code == 0 ? '<span style="color:#46B450">刷新成功</span>' : '<span style="color:#FF5E52">刷新失败</span>' ) . '</strong></p>';
						echo '<p><strong>API返回：</strong><code style="word-break:break-all; padding:0px 0px 0px 5px;">' . ( $refresh_message ? $refresh_message->message : '' ) . '</code></p>';
					} else {
						echo '<p><strong>缓存刷新：</strong>将在发布或更新文章时自动刷新</p>';
					}
				}
			} );
		}

		function admin_menu() {
			// 后台设置
			add_menu_page( esc_html__( 'WP-CDN-Yes', 'wp-cdn-yes' ), esc_html__( 'WP-CDN-Yes', 'wp-cdn-yes' ), 'manage_options', 'wp-cdn-yes', array(
				$this,
				'plugin_page'
			) );
			// 插件页设置
			add_filter( 'plugin_action_links', function ( $links, $file ) {
				if ( 'wp-cdn-yes/wp-cdn-yes.php' !== $file ) {
					return $links;
				}
				$settings_link = '<a href="' . add_query_arg( array( 'page' => 'wp-cdn-yes' ), admin_url( 'admin.php' ) ) . '">' . esc_html__( '设置', 'wp-cdn-yes' ) . '</a>';
				array_unshift( $links, $settings_link );

				return $links;
			}, 10, 2 );
		}

		function get_settings_sections() {
			$sections = array(
				array(
					'id'    => 'wpcy_basics',
					'title' => __( '基础设置', 'wp-cdn-yes' )
				),
				array(
					'id'    => 'wpcy_advanced',
					'title' => __( '高级设置', 'wp-cdn-yes' )
				),
				array(
					'id'    => 'wpcy_about',
					'title' => __( '关于', 'wp-cdn-yes' )
				)
			);

			return $sections;
		}

		function get_settings_fields() {
			$settings_fields = array(
				'wpcy_basics'   => array(
					array(
						'name'    => 'wpcy_cdn_select',
						'label'   => __( 'CDN服务商', 'wp-cdn-yes' ),
						'desc'    => __( '选择您使用CDN的服务商', 'wp-cdn-yes' ),
						'type'    => 'select',
						'default' => 'aliyun_cdn',
						'options' => array(
							'aliyun_cdn'   => __( '阿里云CDN', 'wp-cdn-yes' ),
							'aliyun_dcdn'  => __( '阿里云DCDN（全站加速）', 'wp-cdn-yes' ),
							'tencent_cdn'  => __( '腾讯云CDN', 'wp-cdn-yes' ),
							'tencent_ecdn' => __( '腾讯云ECDN（全站加速）', 'wp-cdn-yes' ),
							'qiniu_cdn'    => __( '七牛云CDN', 'wp-cdn-yes' ),
							'upyun_cdn'    => __( '又拍云CDN', 'wp-cdn-yes' ),
						)
					),
					array(
						'name'        => 'wpcy_cdn_id',
						'label'       => __( 'CDN ID', 'wp-cdn-yes' ),
						'desc'        => __( '输入具有CDN控制权限的账号ID（不是登录账号）', 'wp-cdn-yes' ),
						'placeholder' => __( '您使用CDN的账号ID', 'wp-cdn-yes' ),
						'type'        => 'text',
						'default'     => ''
					),
					array(
						'name'    => 'wpcy_cdn_key',
						'label'   => __( 'CDN KEY', 'wp-cdn-yes' ),
						'desc'    => __( '输入具有CDN控制权限的账号KEY（不是登录账号）', 'wp-cdn-yes' ),
						'type'    => 'password',
						'default' => ''
					),
                    array(
                        'name'    => 'wpcy_notice',
                        'label'   => __( '注意', 'wp-cdn-yes' ),
                        'type'    => 'html',
                        'html'    => __( '<h4>又拍云需前往<a href="https://wp-cdn.cn/upyun_token" target="_blank">https://wp-cdn.cn/upyun_token</a>获取Token</h4><p>然后在CDN ID和CDN KEY均填入Token即可</p>' )
                    ),
					array(
						'name'    => 'wpcy_cdn_refresh_publish',
						'label'   => __( '发布/更新文章清除缓存', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '在文章发表/更新时清除CDN缓存。', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'wpcy_cdn_refresh_trash',
						'label'   => __( '文章移入/移出回收站清除缓存', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '在文章移入/移出回收站时清除CDN缓存。', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'wpcy_cdn_refresh_comment_submitted',
						'label'   => __( '提交评论清除缓存', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '在评论提交时清除CDN缓存。（针对未开启评论审核站点）', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'off'
					),
					array(
						'name'    => 'wpcy_cdn_refresh_comment_approved',
						'label'   => __( '审核评论清除缓存', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '在评论审核通过时清除CDN缓存（针对开启评论审核站点）。', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'wpcy_cdn_refresh_comment_trash',
						'label'   => __( '评论移入/移出回收站清除缓存', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '在评论移入/移出回收站时清除CDN缓存。', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'wpcy_cdn_refresh_category',
						'label'   => __( '分类新增/修改/删除清除缓存', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '在分类新增/修改/删除时清除CDN缓存。', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
				),
				'wpcy_advanced' => array(
					array(
						'name'    => 'wpcy_cdn_refresh_type',
						'label'   => __( 'CDN刷新方式', 'wp-cdn-yes' ),
						'desc'    => __( '设置CDN刷新方式，目录方式相当于刷新全站缓存（仅部分CDN支持）', 'wp-cdn-yes' ),
						'type'    => 'radio',
						'default' => 'url',
						'options' => array(
							'url' => __( '链接', 'wp-cdn-yes' ),
							'dir' => __( '目录', 'wp-cdn-yes' )
						)
					),
					array(
						'name'    => 'wpcy_cdn_static',
						'label'   => __( '静态文件CDN加速', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '该功能正处于实验阶段，可一键将前台静态资源使用公共CDN加速，如开启后访问异常，请关掉它并与我反馈。', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'on'
					),
					array(
						'name'    => 'wpcy_change_cache_control',
						'label'   => __( '修改cache-control', 'wp-cdn-yes' ),
						'value'   => __( '启用', 'wp-cdn-yes' ),
						'desc'    => __( '修改cache-control头为public，使页面得以正常被CDN缓存。', 'wp-cdn-yes' ),
						'type'    => 'checkbox',
						'default' => 'off'
					),
				),
				'wpcy_about'    => array(
					array(
						'name'    => 'wpcy_about_plugin',
						'label'   => __( '关于插件', 'wp-cdn-yes' ),
						'type'    => 'html',
						'html'    => __( '<h4>官网：<a href="https://wp-cdn.cn" target="_blank">https://wp-cdn.cn</a> | 隐私协议：<a href="https://wp-cdn.cn/privacy" target="_blank">https://wp-cdn.cn/privacy</a></h4><p>WP-CDN-Yes是WordPress中国化的一部分，其作用是自动刷新CDN节点缓存以及对前台静态文件CDN加速。</p><p>交流吹水群：<a href="https://jq.qq.com/?k=TeG3OdFI" target="_blank">https://jq.qq.com/?k=TeG3OdFI</a></p><p>维护相关API服务器和节点需要一定的成本，如果可能，不妨赞助使插件发展得更好。</p><img style="margin: 1em;" src="https://img-cdn.haozi.xyz/2021/01/03/425bd8107584511ab68d2d3574916286.png" alt="支付宝" width="200" height="200" /><img style="margin: 1em;" src="https://img-cdn.haozi.xyz/2021/01/03/b5ab8ddf895eb3d99fba5bc451793e24.png" alt="微信" width="200" height="200" />' )
					)
				)
			);

			return $settings_fields;
		}

		function plugin_page() {
			echo '<h1>WP-CDN-Yes</h1>';
			echo '<div class="wrap">';

			$this->settings_api->show_navigation();
			$this->settings_api->show_forms();

			echo '</div>';
		}

	}
endif;
